#[repr(i32)]pub enum ExternalGameCategoryEnum {
Show 21 variants
ExternalgameCategoryNull = 0,
ExternalgameSteam = 1,
ExternalgameGog = 5,
ExternalgameYoutube = 10,
ExternalgameMicrosoft = 11,
ExternalgameApple = 13,
ExternalgameTwitch = 14,
ExternalgameAndroid = 15,
ExternalgameAmazonAsin = 20,
ExternalgameAmazonLuna = 22,
ExternalgameAmazonAdg = 23,
ExternalgameEpicGameStore = 26,
ExternalgameOculus = 28,
ExternalgameUtomik = 29,
ExternalgameItchIo = 30,
ExternalgameXboxMarketplace = 31,
ExternalgameKartridge = 32,
ExternalgamePlaystationStoreUs = 36,
ExternalgameFocusEntertainment = 37,
ExternalgameXboxGamePassUltimateCloud = 54,
ExternalgameGamejolt = 55,
}Variants
ExternalgameCategoryNull = 0
ExternalgameSteam = 1
ExternalgameGog = 5
ExternalgameYoutube = 10
ExternalgameMicrosoft = 11
ExternalgameApple = 13
ExternalgameTwitch = 14
ExternalgameAndroid = 15
ExternalgameAmazonAsin = 20
ExternalgameAmazonLuna = 22
ExternalgameAmazonAdg = 23
ExternalgameEpicGameStore = 26
ExternalgameOculus = 28
ExternalgameUtomik = 29
ExternalgameItchIo = 30
ExternalgameXboxMarketplace = 31
ExternalgameKartridge = 32
ExternalgamePlaystationStoreUs = 36
ExternalgameFocusEntertainment = 37
ExternalgameXboxGamePassUltimateCloud = 54
ExternalgameGamejolt = 55
Implementations
Sourceimpl ExternalGameCategoryEnum
impl ExternalGameCategoryEnum
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ExternalGameCategoryEnum.
Sourcepub fn from_i32(value: i32) -> Option<ExternalGameCategoryEnum>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ExternalGameCategoryEnum>
Converts an i32 to a ExternalGameCategoryEnum, or None if value is not a valid variant.
Sourceimpl ExternalGameCategoryEnum
impl ExternalGameCategoryEnum
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.