#[repr(i32)]pub enum GameCategoryEnum {
Show 15 variants
MainGame = 0,
DlcAddon = 1,
Expansion = 2,
Bundle = 3,
StandaloneExpansion = 4,
Mod = 5,
Episode = 6,
Season = 7,
Remake = 8,
Remaster = 9,
ExpandedGame = 10,
Port = 11,
Fork = 12,
Pack = 13,
Update = 14,
}Variants
MainGame = 0
DlcAddon = 1
Expansion = 2
Bundle = 3
StandaloneExpansion = 4
Mod = 5
Episode = 6
Season = 7
Remake = 8
Remaster = 9
ExpandedGame = 10
Port = 11
Fork = 12
Pack = 13
Update = 14
Implementations
Sourceimpl GameCategoryEnum
impl GameCategoryEnum
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.