pub struct AgeRatingContentDescriptionType {
pub id: u64,
pub slug: String,
pub name: String,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub checksum: String,
}Fields
id: u64slug: Stringname: Stringcreated_at: Option<Timestamp>updated_at: Option<Timestamp>checksum: StringTrait Implementations
Sourceimpl Clone for AgeRatingContentDescriptionType
impl Clone for AgeRatingContentDescriptionType
Sourcefn clone(&self) -> AgeRatingContentDescriptionType
fn clone(&self) -> AgeRatingContentDescriptionType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AgeRatingContentDescriptionType
impl<'de> Deserialize<'de> for AgeRatingContentDescriptionType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for AgeRatingContentDescriptionType
impl Message for AgeRatingContentDescriptionType
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AgeRatingContentDescriptionType
impl PartialEq for AgeRatingContentDescriptionType
Sourcefn eq(&self, other: &AgeRatingContentDescriptionType) -> bool
fn eq(&self, other: &AgeRatingContentDescriptionType) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AgeRatingContentDescriptionType