pub struct Company {Show 22 fields
pub id: u64,
pub change_date: Option<Timestamp>,
pub change_date_category: i32,
pub changed_company_id: Option<Box<Company>>,
pub country: i32,
pub created_at: Option<Timestamp>,
pub description: String,
pub developed: Vec<Game>,
pub logo: Option<CompanyLogo>,
pub name: String,
pub parent: Option<Box<Company>>,
pub published: Vec<Game>,
pub slug: String,
pub start_date: Option<Timestamp>,
pub start_date_category: i32,
pub updated_at: Option<Timestamp>,
pub url: String,
pub websites: Vec<CompanyWebsite>,
pub checksum: String,
pub status: Option<CompanyStatus>,
pub start_date_format: Option<DateFormat>,
pub change_date_format: Option<DateFormat>,
}Fields
id: u64change_date: Option<Timestamp>change_date_category: i32👎Deprecated
changed_company_id: Option<Box<Company>>country: i32created_at: Option<Timestamp>description: Stringdeveloped: Vec<Game>logo: Option<CompanyLogo>name: Stringparent: Option<Box<Company>>published: Vec<Game>slug: Stringstart_date: Option<Timestamp>start_date_category: i32👎Deprecated
updated_at: Option<Timestamp>url: Stringwebsites: Vec<CompanyWebsite>checksum: Stringstatus: Option<CompanyStatus>start_date_format: Option<DateFormat>change_date_format: Option<DateFormat>Implementations
Sourceimpl Company
impl Company
Sourcepub fn change_date_category(&self) -> DateFormatChangeDateCategoryEnum
pub fn change_date_category(&self) -> DateFormatChangeDateCategoryEnum
Returns the enum value of change_date_category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_change_date_category(
&mut self,
value: DateFormatChangeDateCategoryEnum,
)
pub fn set_change_date_category( &mut self, value: DateFormatChangeDateCategoryEnum, )
Sets change_date_category to the provided enum value.
Sourcepub fn start_date_category(&self) -> DateFormatChangeDateCategoryEnum
pub fn start_date_category(&self) -> DateFormatChangeDateCategoryEnum
Returns the enum value of start_date_category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_start_date_category(
&mut self,
value: DateFormatChangeDateCategoryEnum,
)
pub fn set_start_date_category( &mut self, value: DateFormatChangeDateCategoryEnum, )
Sets start_date_category to the provided enum value.