pub struct ExternalGame {Show 15 fields
pub id: u64,
pub category: i32,
pub created_at: Option<Timestamp>,
pub game: Option<Game>,
pub name: String,
pub uid: String,
pub updated_at: Option<Timestamp>,
pub url: String,
pub year: i32,
pub media: i32,
pub platform: Option<Platform>,
pub countries: Vec<i32>,
pub checksum: String,
pub external_game_source: Option<ExternalGameSource>,
pub game_release_format: Option<GameReleaseFormat>,
}Fields
id: u64category: i32👎Deprecated
created_at: Option<Timestamp>game: Option<Game>name: Stringuid: Stringupdated_at: Option<Timestamp>url: Stringyear: i32media: i32👎Deprecated
platform: Option<Platform>countries: Vec<i32>checksum: Stringexternal_game_source: Option<ExternalGameSource>game_release_format: Option<GameReleaseFormat>Implementations
Sourceimpl ExternalGame
impl ExternalGame
Sourcepub fn category(&self) -> ExternalGameCategoryEnum
pub fn category(&self) -> ExternalGameCategoryEnum
Returns the enum value of category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_category(&mut self, value: ExternalGameCategoryEnum)
pub fn set_category(&mut self, value: ExternalGameCategoryEnum)
Sets category to the provided enum value.
Sourcepub fn media(&self) -> ExternalGameMediaEnum
pub fn media(&self) -> ExternalGameMediaEnum
Returns the enum value of media, or the default if the field is set to an invalid enum value.
Sourcepub fn set_media(&mut self, value: ExternalGameMediaEnum)
pub fn set_media(&mut self, value: ExternalGameMediaEnum)
Sets media to the provided enum value.