pub struct GameContentSafetyRating {
pub id: u64,
pub game: Option<Game>,
pub content_safety_rating_dimension: Option<ContentSafetyRatingDimension>,
pub content_safety_rating: Option<ContentSafetyRating>,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub checksum: String,
}Fields
id: u64game: Option<Game>content_safety_rating_dimension: Option<ContentSafetyRatingDimension>content_safety_rating: Option<ContentSafetyRating>created_at: Option<Timestamp>updated_at: Option<Timestamp>checksum: StringTrait Implementations
Sourceimpl Clone for GameContentSafetyRating
impl Clone for GameContentSafetyRating
Sourcefn clone(&self) -> GameContentSafetyRating
fn clone(&self) -> GameContentSafetyRating
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GameContentSafetyRating
impl Debug for GameContentSafetyRating
Sourceimpl Default for GameContentSafetyRating
impl Default for GameContentSafetyRating
Sourceimpl<'de> Deserialize<'de> for GameContentSafetyRating
impl<'de> Deserialize<'de> for GameContentSafetyRating
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for GameContentSafetyRating
impl Message for GameContentSafetyRating
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GameContentSafetyRating
impl PartialEq for GameContentSafetyRating
Sourceimpl Serialize for GameContentSafetyRating
impl Serialize for GameContentSafetyRating
impl StructuralPartialEq for GameContentSafetyRating