pub struct GameTimeToBeat {
pub id: u64,
pub game_id: i32,
pub hastily: i32,
pub normally: i32,
pub completely: i32,
pub count: i32,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub checksum: String,
}Fields
id: u64game_id: i32hastily: i32normally: i32completely: i32count: i32created_at: Option<Timestamp>updated_at: Option<Timestamp>checksum: StringTrait Implementations
Sourceimpl Clone for GameTimeToBeat
impl Clone for GameTimeToBeat
Sourcefn clone(&self) -> GameTimeToBeat
fn clone(&self) -> GameTimeToBeat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GameTimeToBeat
impl Debug for GameTimeToBeat
Sourceimpl Default for GameTimeToBeat
impl Default for GameTimeToBeat
Sourceimpl<'de> Deserialize<'de> for GameTimeToBeat
impl<'de> Deserialize<'de> for GameTimeToBeat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for GameTimeToBeat
impl Hash for GameTimeToBeat
Sourceimpl Message for GameTimeToBeat
impl Message for GameTimeToBeat
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GameTimeToBeat
impl PartialEq for GameTimeToBeat
Sourceimpl Serialize for GameTimeToBeat
impl Serialize for GameTimeToBeat
impl Eq for GameTimeToBeat
impl StructuralPartialEq for GameTimeToBeat