pub struct PlatformVersionReleaseDate {Show 13 fields
pub id: u64,
pub category: i32,
pub created_at: Option<Timestamp>,
pub date: Option<Timestamp>,
pub human: String,
pub m: i32,
pub platform_version: Option<PlatformVersion>,
pub region: i32,
pub updated_at: Option<Timestamp>,
pub y: i32,
pub checksum: String,
pub date_format: Option<DateFormat>,
pub release_region: Option<ReleaseDateRegion>,
}Fields
id: u64category: i32👎Deprecated
created_at: Option<Timestamp>date: Option<Timestamp>human: Stringm: i32platform_version: Option<PlatformVersion>region: i32👎Deprecated
updated_at: Option<Timestamp>y: i32checksum: Stringdate_format: Option<DateFormat>release_region: Option<ReleaseDateRegion>Implementations
Sourceimpl PlatformVersionReleaseDate
impl PlatformVersionReleaseDate
Sourcepub fn category(&self) -> DateFormatChangeDateCategoryEnum
pub fn category(&self) -> DateFormatChangeDateCategoryEnum
Returns the enum value of category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_category(&mut self, value: DateFormatChangeDateCategoryEnum)
pub fn set_category(&mut self, value: DateFormatChangeDateCategoryEnum)
Sets category to the provided enum value.
Sourcepub fn region(&self) -> RegionRegionEnum
pub fn region(&self) -> RegionRegionEnum
Returns the enum value of region, or the default if the field is set to an invalid enum value.
Sourcepub fn set_region(&mut self, value: RegionRegionEnum)
pub fn set_region(&mut self, value: RegionRegionEnum)
Sets region to the provided enum value.