pub struct PlatformWebsite {
pub id: u64,
pub category: i32,
pub trusted: bool,
pub url: String,
pub checksum: String,
pub type: Option<WebsiteType>,
}Fields
id: u64category: i32👎Deprecated
trusted: boolurl: Stringchecksum: Stringtype: Option<WebsiteType>Implementations
Sourceimpl PlatformWebsite
impl PlatformWebsite
Sourcepub fn category(&self) -> WebsiteCategoryEnum
pub fn category(&self) -> WebsiteCategoryEnum
Returns the enum value of category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_category(&mut self, value: WebsiteCategoryEnum)
pub fn set_category(&mut self, value: WebsiteCategoryEnum)
Sets category to the provided enum value.