pub struct InstallationProgressUpdate {
pub game_id: i32,
pub status: i32,
pub metrics: Option<InstallationMetrics>,
}Fields
game_id: i32status: i32metrics: Option<InstallationMetrics>Implementations
Sourceimpl InstallationProgressUpdate
impl InstallationProgressUpdate
Sourcepub fn status(&self) -> InstallationStatus
pub fn status(&self) -> InstallationStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: InstallationStatus)
pub fn set_status(&mut self, value: InstallationStatus)
Sets status to the provided enum value.