pub struct FilterValue {
pub value: String,
pub operator: Option<i32>,
}Fields
value: Stringoperator: Option<i32>Implementations
Sourceimpl FilterValue
impl FilterValue
Sourcepub fn operator(&self) -> FilterOperator
pub fn operator(&self) -> FilterOperator
Returns the enum value of operator, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_operator(&mut self, value: FilterOperator)
pub fn set_operator(&mut self, value: FilterOperator)
Sets operator to the provided enum value.