pub struct EmulatorProfile {
pub id: i32,
pub emulator_id: i32,
pub name: String,
pub supported_extensions: Vec<String>,
pub custom_args: Vec<String>,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub built_in: bool,
}Fields
id: i32emulator_id: i32name: Stringsupported_extensions: Vec<String>custom_args: Vec<String>created_at: Option<Timestamp>updated_at: Option<Timestamp>built_in: boolTrait Implementations
Sourceimpl<'update> AsChangeset for &'update EmulatorProfile
impl<'update> AsChangeset for &'update EmulatorProfile
Sourcetype Changeset = <(Grouped<Eq<emulator_id, <&'update i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>, Grouped<Eq<name, <&'update String as AsExpression<<name as Expression>::SqlType>>::Expression>>, Grouped<Eq<supported_extensions, <&'update Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>, Grouped<Eq<custom_args, <&'update Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>, Option<Grouped<Eq<created_at, <&'update Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'update Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Grouped<Eq<built_in, <&'update bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>) as AsChangeset>::Changeset
type Changeset = <(Grouped<Eq<emulator_id, <&'update i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>, Grouped<Eq<name, <&'update String as AsExpression<<name as Expression>::SqlType>>::Expression>>, Grouped<Eq<supported_extensions, <&'update Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>, Grouped<Eq<custom_args, <&'update Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>, Option<Grouped<Eq<created_at, <&'update Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'update Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Grouped<Eq<built_in, <&'update bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>) as AsChangeset>::Changeset
The update statement this type represents
Sourcefn as_changeset(self) -> <Self as AsChangeset>::Changeset
fn as_changeset(self) -> <Self as AsChangeset>::Changeset
Convert
self into the actual update statement being executedSourceimpl AsChangeset for EmulatorProfile
impl AsChangeset for EmulatorProfile
Sourcetype Changeset = <(Grouped<Eq<emulator_id, <i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>, Grouped<Eq<name, <String as AsExpression<<name as Expression>::SqlType>>::Expression>>, Grouped<Eq<supported_extensions, <Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>, Grouped<Eq<custom_args, <Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Grouped<Eq<built_in, <bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>) as AsChangeset>::Changeset
type Changeset = <(Grouped<Eq<emulator_id, <i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>, Grouped<Eq<name, <String as AsExpression<<name as Expression>::SqlType>>::Expression>>, Grouped<Eq<supported_extensions, <Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>, Grouped<Eq<custom_args, <Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Grouped<Eq<built_in, <bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>) as AsChangeset>::Changeset
The update statement this type represents
Sourcefn as_changeset(self) -> <Self as AsChangeset>::Changeset
fn as_changeset(self) -> <Self as AsChangeset>::Changeset
Convert
self into the actual update statement being executedSourceimpl<__FK> BelongsTo<&Emulator> for EmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Emulator: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<&Emulator> for EmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Emulator: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = emulator_id
type ForeignKeyColumn = emulator_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl<__FK> BelongsTo<&EmulatorProfile> for DefaultEmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a EmulatorProfile: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<&EmulatorProfile> for DefaultEmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a EmulatorProfile: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = emulator_profile_id
type ForeignKeyColumn = emulator_profile_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl<__FK> BelongsTo<Emulator> for EmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Emulator: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<Emulator> for EmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Emulator: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = emulator_id
type ForeignKeyColumn = emulator_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl<__FK> BelongsTo<EmulatorProfile> for DefaultEmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a EmulatorProfile: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<EmulatorProfile> for DefaultEmulatorProfilewhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a EmulatorProfile: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = emulator_profile_id
type ForeignKeyColumn = emulator_profile_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl Clone for EmulatorProfile
impl Clone for EmulatorProfile
Sourcefn clone(&self) -> EmulatorProfile
fn clone(&self) -> EmulatorProfile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmulatorProfile
impl Debug for EmulatorProfile
Sourceimpl Default for EmulatorProfile
impl Default for EmulatorProfile
Sourceimpl<'de> Deserialize<'de> for EmulatorProfile
impl<'de> Deserialize<'de> for EmulatorProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HasTable for EmulatorProfile
impl HasTable for EmulatorProfile
Sourceimpl Hash for EmulatorProfile
impl Hash for EmulatorProfile
Sourceimpl<'ident> Identifiable for &'ident EmulatorProfile
impl<'ident> Identifiable for &'ident EmulatorProfile
Sourceimpl<'insert> Insertable<table> for &'insert EmulatorProfile
impl<'insert> Insertable<table> for &'insert EmulatorProfile
Sourcetype Values = <(Option<Grouped<Eq<id, <&'insert i32 as AsExpression<<id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<emulator_id, <&'insert i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<name, <&'insert String as AsExpression<<name as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<supported_extensions, <&'insert Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<custom_args, <&'insert Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<built_in, <&'insert bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<id, <&'insert i32 as AsExpression<<id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<emulator_id, <&'insert i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<name, <&'insert String as AsExpression<<name as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<supported_extensions, <&'insert Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<custom_args, <&'insert Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<built_in, <&'insert bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<id, &'insert i32>>, Option<Eq<emulator_id, &'insert i32>>, Option<Eq<name, &'insert String>>, Option<Eq<supported_extensions, &'insert Vec<String>>>, Option<Eq<custom_args, &'insert Vec<String>>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>, Option<Eq<built_in, &'insert bool>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<id, &'insert i32>>, Option<Eq<emulator_id, &'insert i32>>, Option<Eq<name, &'insert String>>, Option<Eq<supported_extensions, &'insert Vec<String>>>, Option<Eq<custom_args, &'insert Vec<String>>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>, Option<Eq<built_in, &'insert bool>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Insertable<table> for EmulatorProfile
impl Insertable<table> for EmulatorProfile
Sourcetype Values = <(Option<Grouped<Eq<id, <i32 as AsExpression<<id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<emulator_id, <i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<name, <String as AsExpression<<name as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<supported_extensions, <Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<custom_args, <Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<built_in, <bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<id, <i32 as AsExpression<<id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<emulator_id, <i32 as AsExpression<<emulator_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<name, <String as AsExpression<<name as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<supported_extensions, <Vec<String> as AsExpression<<supported_extensions as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<custom_args, <Vec<String> as AsExpression<<custom_args as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<built_in, <bool as AsExpression<<built_in as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<id, i32>>, Option<Eq<emulator_id, i32>>, Option<Eq<name, String>>, Option<Eq<supported_extensions, Vec<String>>>, Option<Eq<custom_args, Vec<String>>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>, Option<Eq<built_in, bool>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<id, i32>>, Option<Eq<emulator_id, i32>>, Option<Eq<name, String>>, Option<Eq<supported_extensions, Vec<String>>>, Option<Eq<custom_args, Vec<String>>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>, Option<Eq<built_in, bool>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Message for EmulatorProfile
impl Message for EmulatorProfile
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EmulatorProfile
impl PartialEq for EmulatorProfile
Sourceimpl<__DB: Backend, __ST0, __ST1, __ST2, __ST3, __ST4, __ST5, __ST6, __ST7> Queryable<(__ST0, __ST1, __ST2, __ST3, __ST4, __ST5, __ST6, __ST7), __DB> for EmulatorProfile
impl<__DB: Backend, __ST0, __ST1, __ST2, __ST3, __ST4, __ST5, __ST6, __ST7> Queryable<(__ST0, __ST1, __ST2, __ST3, __ST4, __ST5, __ST6, __ST7), __DB> for EmulatorProfile
Sourceimpl<__DB: Backend> Selectable<__DB> for EmulatorProfile
impl<__DB: Backend> Selectable<__DB> for EmulatorProfile
Sourcetype SelectExpression = (id, emulator_id, name, supported_extensions, custom_args, created_at, updated_at, built_in)
type SelectExpression = (id, emulator_id, name, supported_extensions, custom_args, created_at, updated_at, built_in)
The expression you’d like to select. Read more
Sourcefn construct_selection() -> Self::SelectExpression
fn construct_selection() -> Self::SelectExpression
Construct an instance of the expression
Sourceimpl Serialize for EmulatorProfile
impl Serialize for EmulatorProfile
impl Eq for EmulatorProfile
impl StructuralPartialEq for EmulatorProfile
impl UndecoratedInsertRecord<table> for EmulatorProfile