pub struct GameGenreMap {
pub game_id: i32,
pub genre_id: i32,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
game_id: i32genre_id: i32created_at: Option<Timestamp>updated_at: Option<Timestamp>Trait Implementations
Sourceimpl<'update> AsChangeset for &'update GameGenreMap
impl<'update> AsChangeset for &'update GameGenreMap
Sourcetype Changeset = <(Option<Grouped<Eq<created_at, <&'update Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'update Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
type Changeset = <(Option<Grouped<Eq<created_at, <&'update Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'update Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
The update statement this type represents
Sourcefn as_changeset(self) -> <Self as AsChangeset>::Changeset
fn as_changeset(self) -> <Self as AsChangeset>::Changeset
Convert
self into the actual update statement being executedSourceimpl AsChangeset for GameGenreMap
impl AsChangeset for GameGenreMap
Sourcetype Changeset = <(Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
type Changeset = <(Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
The update statement this type represents
Sourcefn as_changeset(self) -> <Self as AsChangeset>::Changeset
fn as_changeset(self) -> <Self as AsChangeset>::Changeset
Convert
self into the actual update statement being executedSourceimpl<__FK> BelongsTo<&Game> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Game: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<&Game> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Game: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = game_id
type ForeignKeyColumn = game_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl<__FK> BelongsTo<&GameGenre> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a GameGenre: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<&GameGenre> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a GameGenre: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = genre_id
type ForeignKeyColumn = genre_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl<__FK> BelongsTo<Game> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Game: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<Game> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a Game: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = game_id
type ForeignKeyColumn = game_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl<__FK> BelongsTo<GameGenre> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a GameGenre: Identifiable<Id = &'__a __FK>,
impl<__FK> BelongsTo<GameGenre> for GameGenreMapwhere
__FK: Hash + Eq,
for<'__a> &'__a i32: Into<Option<&'__a __FK>>,
for<'__a> &'__a GameGenre: Identifiable<Id = &'__a __FK>,
Sourcetype ForeignKey = __FK
type ForeignKey = __FK
The foreign key of this struct
Sourcetype ForeignKeyColumn = genre_id
type ForeignKeyColumn = genre_id
The database column representing the foreign key
of the table this struct represents
Sourcefn foreign_key(&self) -> Option<&Self::ForeignKey>
fn foreign_key(&self) -> Option<&Self::ForeignKey>
Returns the foreign key for
selfSourcefn foreign_key_column() -> Self::ForeignKeyColumn
fn foreign_key_column() -> Self::ForeignKeyColumn
Returns the foreign key column of this struct’s table
Sourceimpl Clone for GameGenreMap
impl Clone for GameGenreMap
Sourcefn clone(&self) -> GameGenreMap
fn clone(&self) -> GameGenreMap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GameGenreMap
impl Debug for GameGenreMap
Sourceimpl Default for GameGenreMap
impl Default for GameGenreMap
Sourceimpl<'de> Deserialize<'de> for GameGenreMap
impl<'de> Deserialize<'de> for GameGenreMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HasTable for GameGenreMap
impl HasTable for GameGenreMap
Sourceimpl Hash for GameGenreMap
impl Hash for GameGenreMap
Sourceimpl<'ident> Identifiable for &'ident GameGenreMap
impl<'ident> Identifiable for &'ident GameGenreMap
Sourceimpl<'insert> Insertable<table> for &'insert GameGenreMap
impl<'insert> Insertable<table> for &'insert GameGenreMap
Sourcetype Values = <(Option<Grouped<Eq<game_id, <&'insert i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<genre_id, <&'insert i32 as AsExpression<<genre_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<game_id, <&'insert i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<genre_id, <&'insert i32 as AsExpression<<genre_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<game_id, &'insert i32>>, Option<Eq<genre_id, &'insert i32>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<game_id, &'insert i32>>, Option<Eq<genre_id, &'insert i32>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Insertable<table> for GameGenreMap
impl Insertable<table> for GameGenreMap
Sourcetype Values = <(Option<Grouped<Eq<game_id, <i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<genre_id, <i32 as AsExpression<<genre_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<game_id, <i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<genre_id, <i32 as AsExpression<<genre_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<game_id, i32>>, Option<Eq<genre_id, i32>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<game_id, i32>>, Option<Eq<genre_id, i32>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Message for GameGenreMap
impl Message for GameGenreMap
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GameGenreMap
impl PartialEq for GameGenreMap
Sourceimpl<__DB: Backend, __ST0, __ST1, __ST2, __ST3> Queryable<(__ST0, __ST1, __ST2, __ST3), __DB> for GameGenreMapwhere
(i32, i32, Option<Timestamp>, Option<Timestamp>): FromStaticSqlRow<(__ST0, __ST1, __ST2, __ST3), __DB>,
impl<__DB: Backend, __ST0, __ST1, __ST2, __ST3> Queryable<(__ST0, __ST1, __ST2, __ST3), __DB> for GameGenreMapwhere
(i32, i32, Option<Timestamp>, Option<Timestamp>): FromStaticSqlRow<(__ST0, __ST1, __ST2, __ST3), __DB>,
Sourceimpl<__DB: Backend> Selectable<__DB> for GameGenreMap
impl<__DB: Backend> Selectable<__DB> for GameGenreMap
Sourcetype SelectExpression = (game_id, genre_id, created_at, updated_at)
type SelectExpression = (game_id, genre_id, created_at, updated_at)
The expression you’d like to select. Read more
Sourcefn construct_selection() -> Self::SelectExpression
fn construct_selection() -> Self::SelectExpression
Construct an instance of the expression
Sourceimpl Serialize for GameGenreMap
impl Serialize for GameGenreMap
impl Copy for GameGenreMap
impl Eq for GameGenreMap
impl StructuralPartialEq for GameGenreMap
impl UndecoratedInsertRecord<table> for GameGenreMap