pub struct NewEmulator {
pub supported_platforms: Vec<i32>,
pub name: String,
pub save_strategy: i32,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub built_in: Option<bool>,
pub libretro_name: Option<String>,
pub operating_systems: Vec<i32>,
}Fields
supported_platforms: Vec<i32>name: Stringsave_strategy: i32created_at: Option<Timestamp>updated_at: Option<Timestamp>built_in: Option<bool>libretro_name: Option<String>operating_systems: Vec<i32>Implementations
Sourceimpl NewEmulator
impl NewEmulator
Sourcepub fn save_strategy(&self) -> SaveStrategy
pub fn save_strategy(&self) -> SaveStrategy
Returns the enum value of save_strategy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_save_strategy(&mut self, value: SaveStrategy)
pub fn set_save_strategy(&mut self, value: SaveStrategy)
Sets save_strategy to the provided enum value.
Sourcepub fn built_in(&self) -> bool
pub fn built_in(&self) -> bool
Returns the value of built_in, or the default value if built_in is unset.
Sourcepub fn libretro_name(&self) -> &str
pub fn libretro_name(&self) -> &str
Returns the value of libretro_name, or the default value if libretro_name is unset.
Sourcepub fn operating_systems(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperatingSystem>>
pub fn operating_systems( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperatingSystem>>
Returns an iterator which yields the valid enum values contained in operating_systems.
Sourcepub fn push_operating_systems(&mut self, value: OperatingSystem)
pub fn push_operating_systems(&mut self, value: OperatingSystem)
Appends the provided enum value to operating_systems.