pub struct NewSimilarGameMap {
pub game_id: i32,
pub similar_game_id: i32,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
game_id: i32similar_game_id: i32created_at: Option<Timestamp>updated_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for NewSimilarGameMap
impl Clone for NewSimilarGameMap
Sourcefn clone(&self) -> NewSimilarGameMap
fn clone(&self) -> NewSimilarGameMap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewSimilarGameMap
impl Debug for NewSimilarGameMap
Sourceimpl Default for NewSimilarGameMap
impl Default for NewSimilarGameMap
Sourceimpl<'de> Deserialize<'de> for NewSimilarGameMap
impl<'de> Deserialize<'de> for NewSimilarGameMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for NewSimilarGameMap
impl Hash for NewSimilarGameMap
Sourceimpl<'insert> Insertable<table> for &'insert NewSimilarGameMap
impl<'insert> Insertable<table> for &'insert NewSimilarGameMap
Sourcetype Values = <(Option<Grouped<Eq<game_id, <&'insert i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <&'insert i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<game_id, <&'insert i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <&'insert i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<game_id, &'insert i32>>, Option<Eq<similar_game_id, &'insert i32>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<game_id, &'insert i32>>, Option<Eq<similar_game_id, &'insert i32>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Insertable<table> for NewSimilarGameMap
impl Insertable<table> for NewSimilarGameMap
Sourcetype Values = <(Option<Grouped<Eq<game_id, <i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<game_id, <i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<game_id, i32>>, Option<Eq<similar_game_id, i32>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<game_id, i32>>, Option<Eq<similar_game_id, i32>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Message for NewSimilarGameMap
impl Message for NewSimilarGameMap
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NewSimilarGameMap
impl PartialEq for NewSimilarGameMap
Sourceimpl Serialize for NewSimilarGameMap
impl Serialize for NewSimilarGameMap
impl Copy for NewSimilarGameMap
impl Eq for NewSimilarGameMap
impl StructuralPartialEq for NewSimilarGameMap
impl UndecoratedInsertRecord<table> for NewSimilarGameMap