pub struct UpdatedSimilarGameMap {
pub game_id: i32,
pub similar_game_id: i32,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
game_id: i32similar_game_id: i32created_at: Option<Timestamp>updated_at: Option<Timestamp>Trait Implementations
Sourceimpl<'update> AsChangeset for &'update UpdatedSimilarGameMap
impl<'update> AsChangeset for &'update UpdatedSimilarGameMap
Sourcetype Changeset = <(Option<Grouped<Eq<created_at, <&'update Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'update Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
type Changeset = <(Option<Grouped<Eq<created_at, <&'update Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'update Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
The update statement this type represents
Sourcefn as_changeset(self) -> <Self as AsChangeset>::Changeset
fn as_changeset(self) -> <Self as AsChangeset>::Changeset
Convert
self into the actual update statement being executedSourceimpl AsChangeset for UpdatedSimilarGameMap
impl AsChangeset for UpdatedSimilarGameMap
Sourcetype Changeset = <(Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
type Changeset = <(Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as AsChangeset>::Changeset
The update statement this type represents
Sourcefn as_changeset(self) -> <Self as AsChangeset>::Changeset
fn as_changeset(self) -> <Self as AsChangeset>::Changeset
Convert
self into the actual update statement being executedSourceimpl Clone for UpdatedSimilarGameMap
impl Clone for UpdatedSimilarGameMap
Sourcefn clone(&self) -> UpdatedSimilarGameMap
fn clone(&self) -> UpdatedSimilarGameMap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdatedSimilarGameMap
impl Debug for UpdatedSimilarGameMap
Sourceimpl Default for UpdatedSimilarGameMap
impl Default for UpdatedSimilarGameMap
Sourceimpl<'de> Deserialize<'de> for UpdatedSimilarGameMap
impl<'de> Deserialize<'de> for UpdatedSimilarGameMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HasTable for UpdatedSimilarGameMap
impl HasTable for UpdatedSimilarGameMap
Sourceimpl Hash for UpdatedSimilarGameMap
impl Hash for UpdatedSimilarGameMap
Sourceimpl<'ident> Identifiable for &'ident UpdatedSimilarGameMap
impl<'ident> Identifiable for &'ident UpdatedSimilarGameMap
Sourceimpl<'insert> Insertable<table> for &'insert UpdatedSimilarGameMap
impl<'insert> Insertable<table> for &'insert UpdatedSimilarGameMap
Sourcetype Values = <(Option<Grouped<Eq<game_id, <&'insert i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <&'insert i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<game_id, <&'insert i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <&'insert i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<game_id, &'insert i32>>, Option<Eq<similar_game_id, &'insert i32>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<game_id, &'insert i32>>, Option<Eq<similar_game_id, &'insert i32>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Insertable<table> for UpdatedSimilarGameMap
impl Insertable<table> for UpdatedSimilarGameMap
Sourcetype Values = <(Option<Grouped<Eq<game_id, <i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<game_id, <i32 as AsExpression<<game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<similar_game_id, <i32 as AsExpression<<similar_game_id as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<game_id, i32>>, Option<Eq<similar_game_id, i32>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<game_id, i32>>, Option<Eq<similar_game_id, i32>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Message for UpdatedSimilarGameMap
impl Message for UpdatedSimilarGameMap
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdatedSimilarGameMap
impl PartialEq for UpdatedSimilarGameMap
Sourceimpl Serialize for UpdatedSimilarGameMap
impl Serialize for UpdatedSimilarGameMap
impl Copy for UpdatedSimilarGameMap
impl Eq for UpdatedSimilarGameMap
impl StructuralPartialEq for UpdatedSimilarGameMap
impl UndecoratedInsertRecord<table> for UpdatedSimilarGameMap