pub struct InstallationIndex {
pub installations: HashMap<i32, i32>,
}Fields
installations: HashMap<i32, i32>game_id -> status
Implementations
Sourceimpl InstallationIndex
impl InstallationIndex
Sourcepub fn get_installations(&self, key: i32) -> Option<InstallationStatus>
pub fn get_installations(&self, key: i32) -> Option<InstallationStatus>
Returns the enum value for the corresponding key in installations, or None if the entry does not exist or it is not a valid enum value.
Sourcepub fn insert_installations(
&mut self,
key: i32,
value: InstallationStatus,
) -> Option<InstallationStatus>
pub fn insert_installations( &mut self, key: i32, value: InstallationStatus, ) -> Option<InstallationStatus>
Inserts a key value pair into installations.