pub struct NewPlatform {
pub path: String,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub deleted_at: Option<Timestamp>,
pub is_deleted: bool,
pub third_party: bool,
}Fields
path: Stringcreated_at: Option<Timestamp>updated_at: Option<Timestamp>deleted_at: Option<Timestamp>is_deleted: boolthird_party: boolTrait Implementations
Sourceimpl Clone for NewPlatform
impl Clone for NewPlatform
Sourcefn clone(&self) -> NewPlatform
fn clone(&self) -> NewPlatform
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewPlatform
impl Debug for NewPlatform
Sourceimpl Default for NewPlatform
impl Default for NewPlatform
Sourceimpl<'de> Deserialize<'de> for NewPlatform
impl<'de> Deserialize<'de> for NewPlatform
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for NewPlatform
impl Hash for NewPlatform
Sourceimpl<'insert> Insertable<table> for &'insert NewPlatform
impl<'insert> Insertable<table> for &'insert NewPlatform
Sourcetype Values = <(Option<Grouped<Eq<path, <&'insert String as AsExpression<<path as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<deleted_at, <&'insert Timestamp as AsExpression<<deleted_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<is_deleted, <&'insert bool as AsExpression<<is_deleted as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<third_party, <&'insert bool as AsExpression<<third_party as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<path, <&'insert String as AsExpression<<path as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <&'insert Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <&'insert Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<deleted_at, <&'insert Timestamp as AsExpression<<deleted_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<is_deleted, <&'insert bool as AsExpression<<is_deleted as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<third_party, <&'insert bool as AsExpression<<third_party as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<path, &'insert String>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>, Option<Eq<deleted_at, &'insert Timestamp>>, Option<Eq<is_deleted, &'insert bool>>, Option<Eq<third_party, &'insert bool>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<path, &'insert String>>, Option<Eq<created_at, &'insert Timestamp>>, Option<Eq<updated_at, &'insert Timestamp>>, Option<Eq<deleted_at, &'insert Timestamp>>, Option<Eq<is_deleted, &'insert bool>>, Option<Eq<third_party, &'insert bool>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Insertable<table> for NewPlatform
impl Insertable<table> for NewPlatform
Sourcetype Values = <(Option<Grouped<Eq<path, <String as AsExpression<<path as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<deleted_at, <Timestamp as AsExpression<<deleted_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<is_deleted, <bool as AsExpression<<is_deleted as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<third_party, <bool as AsExpression<<third_party as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
type Values = <(Option<Grouped<Eq<path, <String as AsExpression<<path as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<created_at, <Timestamp as AsExpression<<created_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<updated_at, <Timestamp as AsExpression<<updated_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<deleted_at, <Timestamp as AsExpression<<deleted_at as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<is_deleted, <bool as AsExpression<<is_deleted as Expression>::SqlType>>::Expression>>>, Option<Grouped<Eq<third_party, <bool as AsExpression<<third_party as Expression>::SqlType>>::Expression>>>) as Insertable<table>>::Values
The
VALUES clause to insert these records Read moreSourcefn values(
self,
) -> <(Option<Eq<path, String>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>, Option<Eq<deleted_at, Timestamp>>, Option<Eq<is_deleted, bool>>, Option<Eq<third_party, bool>>) as Insertable<table>>::Values
fn values( self, ) -> <(Option<Eq<path, String>>, Option<Eq<created_at, Timestamp>>, Option<Eq<updated_at, Timestamp>>, Option<Eq<deleted_at, Timestamp>>, Option<Eq<is_deleted, bool>>, Option<Eq<third_party, bool>>) as Insertable<table>>::Values
Construct
Self::Values Read moreSourcefn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
fn insert_into(self, table: T) -> InsertStatement<T, Self::Values>
Insert
self into a given table. Read moreSourceimpl Message for NewPlatform
impl Message for NewPlatform
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NewPlatform
impl PartialEq for NewPlatform
Sourceimpl Serialize for NewPlatform
impl Serialize for NewPlatform
impl Eq for NewPlatform
impl StructuralPartialEq for NewPlatform
impl UndecoratedInsertRecord<table> for NewPlatform